@@ -1,5 +1,5 @@
 package SimpleDB::Class::Role::Itemized;
-our $VERSION = '1.0103';
+our $VERSION = '1.0200';
 
 use Moose::Role;
 use SimpleDB::Class::Types ':all';
@@ -12,7 +12,7 @@ SimpleDB::Class::Role::Itemized - Provides utility methods to classes that need
 
 =head1 VERSION
 
-version 1.0103
+version 1.0200
 
 =head1 SYNOPSIS
 
@@ -50,11 +50,11 @@ An optional id to instantiate the item with.
 
 sub instantiate_item {
     my ($self, $attributes, $id) = @_;
-    my %params = (simpledb=>$self->simpledb);
+    $attributes->{simpledb} = $self->simpledb;
     if (defined $id && $id ne '') {
-        $params{id} = $id;
+        $attributes->{id} = $id;
     }
-    return $self->determine_item_class($attributes)->new(%params)->update($attributes);
+    return $self->determine_item_class($attributes)->new($attributes);
 }
 
 #--------------------------------------------------------
@@ -134,7 +134,9 @@ sub parse_item {
     my $item_class = $self->determine_item_class($attributes);
 
     # now we're ready to instantiate
-    return $item_class->new(simpledb=>$self->simpledb, id=>$id)->update($attributes);
+    $attributes->{simpledb} = $self->simpledb;
+    $attributes->{id} = $id;
+    return $item_class->new($attributes);
 }
 
 =head1 LEGAL
